require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmclassification',
  dscmeta_resource_friendly_name: 'FSRMClassification',
  dscmeta_resource_name: 'DSC_FSRMClassification',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: 'The DSC FSRMClassification resource type.
         Automatically generated from version 2.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_lasterror: {
      type: 'Optional[String]',
      desc: ' ',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_continuouslogsize: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The maximum number of KB that can be used for the continuous mode log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_schedulemonthly: {
      type: 'Optional[Array[Integer[0, 4294967295]]]',
      desc: 'An array of days of the month the FSRM Classification should run on.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32[]',
      mof_is_embedded: false,
    },
    dsc_id: {
      type: 'String',
      desc: 'This is a unique identifier for this resource.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletime: {
      type: 'Optional[String]',
      desc: 'A string containing the time of day the FSRM Classification should run at.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_continuouslog: {
      type: 'Optional[Boolean]',
      desc: 'Enable FSRM Classification continuous mode logging.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excludenamespace: {
      type: 'Optional[Array[String]]',
      desc: 'An array of Namespaces that will be excluded from FSRM Classification.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_schedulerunduration: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The maximum number of hours the FSRM Classification can run for. Setting this to -1 will disable this.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_scheduleweekly: {
      type: 'Optional[Array[String]]',
      desc: 'An array of named days of the week the FSRM Classification should run on.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_status: {
      type: 'Optional[String]',
      desc: ' ',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_continuous: {
      type: 'Optional[Boolean]',
      desc: 'Enable FSRM Classification continuous mode for new files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
