require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmclassificationrule',
  dscmeta_resource_friendly_name: 'FSRMClassificationRule',
  dscmeta_resource_name: 'DSC_FSRMClassificationRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: 'The DSC FSRMClassificationRule resource type.
         Automatically generated from version 2.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_flags: {
      type: 'Optional[Array[String]]',
      desc: 'An array of flags that defines the possible states of the rule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the FSRM Classification Rule.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentregularexpression: {
      type: 'Optional[Array[String]]',
      desc: 'An array of regular expressions for pattern matching.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_namespace: {
      type: 'Optional[Array[String]]',
      desc: 'An array of namespaces where the rule is applied.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_disabled: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that the classification rule is disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_contentstring: {
      type: 'Optional[Array[String]]',
      desc: 'An array of strings for the content classifier to search for.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_parameters: {
      type: 'Optional[Array[String]]',
      desc: 'An array of parameters in the format <name>=<value> that can be used by the File Classification Infrastructure.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_reevaluateproperty: {
      type: "Optional[Enum['Never', 'Overwrite', 'Aggregate']]",
      desc: 'Specifies the evaluation policy of the rule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the FSRM Classification Rule should exist.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentstringcasesensitive: {
      type: 'Optional[Array[String]]',
      desc: 'An array of case sensitive strings for the content classifier to search for.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'The description for the FSRM Classification Rule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_classificationmechanism: {
      type: 'Optional[String]',
      desc: 'Specifies the name of a valid classification mechanism available on the server for assigning the property value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_propertyvalue: {
      type: 'Optional[String]',
      desc: 'Specifies the property value that the rule will assign.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_property: {
      type: 'Optional[String]',
      desc: 'Specifies the name of a classification property definition to set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
