require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmfilescreentemplateaction',
  dscmeta_resource_friendly_name: 'FSRMFileScreenTemplateAction',
  dscmeta_resource_name: 'DSC_FSRMFileScreenTemplateAction',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: 'The DSC FSRMFileScreenTemplateAction resource type.
         Automatically generated from version 2.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_killtimeout: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Int containing kill timeout of the command. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_workingdirectory: {
      type: 'Optional[String]',
      desc: 'The working directory of the command. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_body: {
      type: 'Optional[String]',
      desc: 'The body text of the e-mail or event. Required when Type is Email or Event.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the FSRM File Screen Template that this Action is attached to.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_command: {
      type: 'Optional[String]',
      desc: 'The Command to execute. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runlimitinterval: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Int containing the run limit interval of the command. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_mailto: {
      type: 'Optional[String]',
      desc: 'The mail to of the e-mail sent. Required when Type is Email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_type: {
      type: "Enum['Email', 'Event', 'Command', 'Report']",
      desc: 'The type of FSRM Action.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the FSRM Action should exist.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reporttypes: {
      type: 'Optional[Array[String]]',
      desc: 'Array of Reports to create. Required when Type is Report.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_mailbcc: {
      type: 'Optional[String]',
      desc: 'The mail BCC of the e-mail sent. Required when Type is Email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_commandparameters: {
      type: 'Optional[String]',
      desc: 'The Command Parameters. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_eventtype: {
      type: "Optional[Enum['None', 'Information', 'Warning', 'Error']]",
      desc: 'The type of event created. Required when Type is Event.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailcc: {
      type: 'Optional[String]',
      desc: 'The mail CC of the e-mail sent. Required when Type is Email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_subject: {
      type: 'Optional[String]',
      desc: 'The subject of the e-mail sent. Required when Type is Email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securitylevel: {
      type: "Optional[Enum['None', 'LocalService', 'NetworkService', 'LocalSystem']]",
      desc: 'The security level the command runs under. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_shouldlogerror: {
      type: 'Optional[Boolean]',
      desc: 'Boolean specifying if command errors should be logged. Required when Type is Command.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
