require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmquota',
  dscmeta_resource_friendly_name: 'FSRMQuota',
  dscmeta_resource_name: 'DSC_FSRMQuota',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: 'The DSC FSRMQuota resource type.
         Automatically generated from version 2.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_size: {
      type: 'Optional[Integer[-9223372036854775808, 9223372036854775807]]',
      desc: 'The size in bytes of this FSRM Quota limit.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt64',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the FSRM Quota should exist.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_matchestemplate: {
      type: 'Optional[Boolean]',
      desc: 'Causes the template to use only the template name and ignore Size, SoftLimit and ThresholdPercentage parameters.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disabled: {
      type: 'Optional[Boolean]',
      desc: 'Disables the FSRM Quota applied to this path.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_template: {
      type: 'Optional[String]',
      desc: 'The name of the FSRM Quota Template to apply to this path.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_softlimit: {
      type: 'Optional[Boolean]',
      desc: 'Controls whether this FSRM Quota has a hard or soft limit.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'An optional description for this FSRM Quota.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'The path this FSRM Quota applies to.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_thresholdpercentages: {
      type: 'Optional[Array[Integer[0, 4294967295]]]',
      desc: 'An array of threshold percentages in this FSRM Quota.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32[]',
      mof_is_embedded: false,
    },
  },
)
