require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_fsrmsettings',
  dscmeta_resource_friendly_name: 'FSRMSettings',
  dscmeta_resource_name: 'DSC_FSRMSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'FSRMDsc',
  dscmeta_module_version: '2.5.0',
  docs: 'The DSC FSRMSettings resource type.
         Automatically generated from version 2.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_adminemailaddress: {
      type: 'Optional[String]',
      desc: 'Specifies a semicolon-separated list of email addresses for the recipients of any email that the server sends to the administrator.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_fromemailaddress: {
      type: 'Optional[String]',
      desc: 'Specifies the default email address from which FSRM sends email messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_eventnotificationlimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the minimum number of seconds between individual running events of an event-type notification.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_smtpserver: {
      type: 'Optional[String]',
      desc: 'Specifies the fully qualified domain name (FQDN) or IP address of the SMTP server that FSRM uses to send email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_emailnotificationlimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the minimum number of seconds between individual running events of an email-type notification.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_commandnotificationlimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the minimum number of seconds between individual running events of a command-type notification.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
